# Compiling documentation

First, execute doctests by running the following command in this dirrectory
```
make doctest
```

If all tests are passed, run
```
make html
```

To view the compiled documentation open the file `_build/html/index.html`.
